/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "ProgressEvent.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomEvent.h"
#include "gdom/GdomProgressEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomEvent.h"
#include "gdom/PrivateGdomProgressEvent.h"
#include "gdom/PrivateIntGdomProgressEvent.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMProgressEvent::GDOMProgressEvent(PassRefPtr<WebCore::ProgressEvent> impl)
    : GDOMEvent(impl)
{
}

void
gdom_progress_event_init_progress_event (GdomProgressEvent *thiz, gchar * type_arg, gboolean can_bubble_arg, gboolean cancelable_arg, gboolean length_computable_arg, gulong loaded_arg, gulong total_arg)
{
    g_return_if_fail (thiz);
    WebCore::ProgressEvent * item = (gdom_progress_event_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (type_arg);
    WebCore::String _g_type_arg = WebCore::String::fromUTF8(type_arg);
    item->initProgressEvent(_g_type_arg, can_bubble_arg, cancelable_arg, length_computable_arg, loaded_arg, total_arg);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "ProgressEvent.h"
#include <gdom/GdomProgressEvent.h>
#include <gdom/PrivateGdomProgressEvent.h>
#include <gdom/PrivateIntGdomProgressEvent.h>
#include <gdom/GdomProgressEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomProgressEvent, gdom_progress_event, GDOM_TYPE_EVENT);

/*
struct _GdomProgressEventPrivate {
    class WebCore::ProgressEvent *item;
};

#define GDOM_PROGRESS_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_PROGRESS_EVENT, GdomProgressEventPrivate))
*/
G_END_DECLS
WebCore::ProgressEvent *
gdom_progress_event_get_private(GdomProgressEvent *request)
{
    GDOMProgressEvent *res;
    res = static_cast<GDOMProgressEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::ProgressEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_LENGTH_COMPUTABLE,
    PROP_LOADED,
    PROP_TOTAL,
};


static void gdom_progress_event_finalize(GObject* object)
{
    /*GdomProgressEvent* request = GDOM_PROGRESS_EVENT(object);*/
    /*GdomProgressEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_progress_event_parent_class)->finalize(object);
}

static void gdom_progress_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomProgressEvent *self = GDOM_PROGRESS_EVENT(object);
    WebCore::ProgressEvent * gself = (gdom_progress_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_progress_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomProgressEvent *self = GDOM_PROGRESS_EVENT(object);
    WebCore::ProgressEvent * gself = (gdom_progress_event_get_private(self));
    switch (prop_id) {
    case PROP_LENGTH_COMPUTABLE:
    {
         g_value_set_boolean (value, gself->lengthComputable());
         break;
    }
    case PROP_LOADED:
    {
         g_value_set_ulong (value, gself->loaded());
         break;
    }
    case PROP_TOTAL:
    {
         g_value_set_ulong (value, gself->total());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_progress_event_class_init(GdomProgressEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_progress_event_finalize;
    g_klass->set_property = gdom_progress_event__set_property_fn;
    g_klass->get_property = gdom_progress_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_LENGTH_COMPUTABLE,
            g_param_spec_boolean ("length_computable", /* name */
                "progress_event_length_computable", /* short description */
                "read-only  gboolean ProgressEvent.length_computable", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LOADED,
            g_param_spec_ulong ("loaded", /* name */
                "progress_event_loaded", /* short description */
                "read-only  gulong ProgressEvent.loaded", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_TOTAL,
            g_param_spec_ulong ("total", /* name */
                "progress_event_total", /* short description */
                "read-only  gulong ProgressEvent.total", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomProgressEventPrivate));*/
}

static void gdom_progress_event_init(GdomProgressEvent* request)
{
    /*GdomProgressEventPrivate* priv = GDOM_PROGRESS_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

